@@ -147,9 +147,7 @@ class ProjectInitializer:
         """
         if not self.args.local:
             self.github_token = os.environ.get("GIT_AUTOMATION")
-            self.repo_link = self.create_github_repo(
-                    self.args.repo_name, self.args.private
-                    )
+            self.create_github_repo(self.args.repo_name, self.args.private)
 
         self.create_local_repo(self.args.repo_name, self.args.path)
 
